spannertools.BracketSpanner
===========================

.. abjad-lineage:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner

.. autoclass:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.written_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner.__repr__
   :noindex:
